@@ -9,7 +9,7 @@ from tinylinks.models import Tinylink
 
 class TinylinkAdmin(admin.ModelAdmin):
     list_display = ('short_url', 'url_truncated', 'amount_of_views', 'user',
-                    'last_checked', 'is_broken', 'validation_error')
+                    'last_checked', 'status', 'validation_error')
     search_fields = ['short_url', 'long_url']
     form = TinylinkAdminForm
 
@@ -17,5 +17,11 @@ class TinylinkAdmin(admin.ModelAdmin):
         return truncatechars(obj.long_url, 60)
     url_truncated.short_description = _('Long URL')
 
+    def status(self, obj):
+        if not obj.is_broken:
+            return _('OK')
+        return _('Link broken')
+    status.short_description = _('Status')
+
 
 admin.site.register(Tinylink, TinylinkAdmin)
